Contents
========

CCL Lexer for the Cerner Command Language.
This module extends the *SqlLexer* lexer of `Pygments`_ to support more
keywords of CCL.

Installation
============

Use the following commands to install the package::

    $ cd pygments-sql-pl-lexer
    $ [sudo] python setup.py install

Check if the lexer is present
=============================

Simply grep the output of the following command for **ccl**.::

    $ pygmentize -L lexers | grep ccl

Use the lexer in LaTeX
======================

Replace <language> with **ccl**::

    \begin{minted}{<language>}
        <code>
    \end{minted}

For example::

    \begin{minted}[linenos=true,frame=single]{ccl}
    --#SET TERMINATOR @

    CREATE OR REPLACE MODULE project @
    \end{minted}




